@@ -1,5 +1,7 @@
 package JiftyX::Fixtures::Script;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
+
+# ABSTRACT: Main script package handling dispatch for subcommands
 
 use strict;
 use warnings;
@@ -13,11 +15,11 @@ use base qw(App::CLI App::CLI::Command);
 __END__
 =head1 NAME
 
-JiftyX::Fixtures::Script
+JiftyX::Fixtures::Script - Main script package handling dispatch for subcommands
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 AUTHOR
 
